==> blesta-5.10.2.zip: blesta/plugins/order/language/es_es/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.!error.captcha.invalid'] = 'El captcha introducido no es válido. Por favor, inténtelo de nuevo.';
$lang['Signup.!error.not_client_owner'] = 'Debe iniciar sesión como propietario del cliente para poder continuar.';
$lang['Signup.!notice.force_email_usernames'] = 'Tu nombre de usuario será el mismo que tu dirección de correo electrónico.';
$lang['Signup.!notice.email_verification'] = 'Se ha enviado un mensaje para verificar su dirección de correo electrónico. Por favor, complete la verificación lo antes posible.';
$lang['Signup.index.field_taxid'] = 'Número de identificación fiscal/VATIN';
$lang['Signup.index.field_firstname'] = 'Nombre';
$lang['Signup.index.field_lastname'] = 'Apellido';
$lang['Signup.index.field_company'] = 'Empresa/Org.';
$lang['Signup.index.field_address1'] = 'Dirección 1';
$lang['Signup.index.field_address2'] = 'Dirección 2';
$lang['Signup.index.field_city'] = 'Ciudad';
$lang['Signup.index.field_state'] = 'Estado/Provincia';
$lang['Signup.index.field_zip'] = 'Código postal';
$lang['Signup.index.field_country'] = 'País';
$lang['Signup.index.field_title'] = 'Título';
$lang['Signup.index.field_phone'] = 'Teléfono';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_email'] = 'Correo electrónico';
$lang['Signup.index.field_username_type_email'] = 'Utilizar el correo electrónico como nombre de usuario';
$lang['Signup.index.field_username_type_username'] = 'Especifique un nombre de usuario';
$lang['Signup.index.field_action_continue'] = 'Continuar como %1$s %2$s';
$lang['Signup.index.field_action_login'] = 'Iniciar sesión';
$lang['Signup.index.field_action_signup'] = 'Crear una cuenta';
$lang['Signup.index.field_username'] = 'Nombre de usuario';
$lang['Signup.index.field_password'] = 'Contraseña';
$lang['Signup.index.field_newpassword'] = 'Contraseña';
$lang['Signup.index.field_confirmpassword'] = 'Confirmar contraseña';
$lang['Signup.index.field_receive_email_marketing'] = 'Deseo recibir correos electrónicos sobre nuevos productos, servicios y ofertas.';
$lang['Signup.index.login_btn'] = 'Conectarse';
$lang['Signup.index.continue_btn'] = 'Continuar con la compra';
$lang['Signup.index.signup_btn'] = 'Crear una cuenta';
$lang['Signup.!error.email.blacklist'] = 'Su pedido no puede ser procesado en este momento.';
$lang['Signup.index.field_recovery_email'] = 'Correo electrónico de recuperación (opcional)';

==> blesta-5.11.4.zip: blesta/plugins/order/language/es_es/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.!error.captcha.invalid'] = 'El captcha introducido no es válido. Por favor, inténtelo de nuevo.';
$lang['Signup.!error.not_client_owner'] = 'Debe iniciar sesión como propietario del cliente para poder continuar.';
$lang['Signup.!notice.force_email_usernames'] = 'Tu nombre de usuario será el mismo que tu dirección de correo electrónico.';
$lang['Signup.!notice.email_verification'] = 'Se ha enviado un mensaje para verificar su dirección de correo electrónico. Por favor, complete la verificación lo antes posible.';
$lang['Signup.index.field_taxid'] = 'Número de identificación fiscal/VATIN';
$lang['Signup.index.field_firstname'] = 'Nombre';
$lang['Signup.index.field_lastname'] = 'Apellido';
$lang['Signup.index.field_company'] = 'Empresa/Org.';
$lang['Signup.index.field_address1'] = 'Dirección 1';
$lang['Signup.index.field_address2'] = 'Dirección 2';
$lang['Signup.index.field_city'] = 'Ciudad';
$lang['Signup.index.field_state'] = 'Estado/Provincia';
$lang['Signup.index.field_zip'] = 'Código postal';
$lang['Signup.index.field_country'] = 'País';
$lang['Signup.index.field_title'] = 'Título';
$lang['Signup.index.field_phone'] = 'Teléfono';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_email'] = 'Correo electrónico';
$lang['Signup.index.field_username_type_email'] = 'Utilizar el correo electrónico como nombre de usuario';
$lang['Signup.index.field_username_type_username'] = 'Especifique un nombre de usuario';
$lang['Signup.index.field_action_continue'] = 'Continuar como %1$s %2$s';
$lang['Signup.index.field_action_login'] = 'Iniciar sesión';
$lang['Signup.index.field_action_signup'] = 'Crear una cuenta';
$lang['Signup.index.field_username'] = 'Nombre de usuario';
$lang['Signup.index.field_password'] = 'Contraseña';
$lang['Signup.index.field_newpassword'] = 'Contraseña';
$lang['Signup.index.field_confirmpassword'] = 'Confirmar contraseña';
$lang['Signup.index.field_receive_email_marketing'] = 'Deseo recibir correos electrónicos sobre nuevos productos, servicios y ofertas.';
$lang['Signup.index.login_btn'] = 'Conectarse';
$lang['Signup.index.continue_btn'] = 'Continuar con la compra';
$lang['Signup.index.signup_btn'] = 'Crear una cuenta';
$lang['Signup.!error.email.blacklist'] = 'Su pedido no puede ser procesado en este momento.';
$lang['Signup.index.field_recovery_email'] = 'Correo electrónico de recuperación (opcional)';
$lang['Signup.otp.field_submit'] = 'Iniciar sesión';
$lang['Signup.otp.field_otp'] = 'Contraseña única';
$lang['Signup.otp.login_heading'] = 'Iniciar sesión';
$lang['Signup.otp.description'] = 'Introduzca su contraseña de un solo uso.';
$lang['Signup.otp.page_title'] = 'Iniciar sesión';
$lang['Signup.index.field_agree_tos'] = 'He leído y acepto los <a href="%1$s" target="_blank">Términos y Condiciones</a>';
$lang['Signup.!error.invalid_agree_tos'] = 'Debe confirmar que acepta las condiciones.';
